cmputil

package
v0.0.0-...-ea698ce Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 25, 2021 License: BSD-3-Clause Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IgnoreISO8601

func IgnoreISO8601() cmp.Option

IgnoreISO8601 ignores any Go strings that matches the ISO8601 format.

func TransformJSON

func TransformJSON() cmp.Option

transformJSON transforms any Go string that looks like JSON into a generic data structure that represents that JSON input. We use an AcyclicTransformer to avoid having the transformer apply on outputs of itself (lest we get stuck in infinite recursion).

Types

This section is empty.

Jump to