Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IgnoreISO8601 ¶
IgnoreISO8601 ignores any Go strings that matches the ISO8601 format.
func TransformJSON ¶
transformJSON transforms any Go string that looks like JSON into a generic data structure that represents that JSON input. We use an AcyclicTransformer to avoid having the transformer apply on outputs of itself (lest we get stuck in infinite recursion).
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.